

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (inaki@blueleaf.cc)
-}

#define ENABLE_OVERLOADING (MIN_VERSION_haskell_gi_overloading(1,0,0) \
       && !defined(__HADDOCK_VERSION__))

module GI.GIRepository.Flags
    ( 

 -- * Flags
-- ** FieldInfoFlags #flag:FieldInfoFlags#

    FieldInfoFlags(..)                      ,


-- ** FunctionInfoFlags #flag:FunctionInfoFlags#

    FunctionInfoFlags(..)                   ,


-- ** RepositoryLoadFlags #flag:RepositoryLoadFlags#

    RepositoryLoadFlags(..)                 ,


-- ** VFuncInfoFlags #flag:VFuncInfoFlags#

    VFuncInfoFlags(..)                      ,




    ) where

import Data.GI.Base.ShortPrelude
import qualified Data.GI.Base.ShortPrelude as SP
import qualified Data.GI.Base.Overloading as O
import qualified Prelude as P

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.GI.Base.ManagedPtr as B.ManagedPtr
import qualified Data.GI.Base.GClosure as B.GClosure
import qualified Data.GI.Base.GError as B.GError
import qualified Data.GI.Base.GVariant as B.GVariant
import qualified Data.GI.Base.GValue as B.GValue
import qualified Data.GI.Base.GParamSpec as B.GParamSpec
import qualified Data.GI.Base.CallStack as B.CallStack
import qualified Data.GI.Base.Properties as B.Properties
import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map
import qualified Foreign.Ptr as FP
import qualified GHC.OverloadedLabels as OL


-- Flags VFuncInfoFlags
{- |
Flags of a @/GIVFuncInfo/@ struct.
-}
data VFuncInfoFlags = 
      VFuncInfoFlagsMustChainUp
    {- ^
    chains up to the parent type
    -}
    | VFuncInfoFlagsMustOverride
    {- ^
    overrides
    -}
    | VFuncInfoFlagsMustNotOverride
    {- ^
    does not override
    -}
    | VFuncInfoFlagsThrows
    {- ^
    Includes a 'GError'
    -}
    | AnotherVFuncInfoFlags Int
    -- ^ Catch-all for unknown values
    deriving (Show, Eq)

instance P.Enum VFuncInfoFlags where
    fromEnum VFuncInfoFlagsMustChainUp = 1
    fromEnum VFuncInfoFlagsMustOverride = 2
    fromEnum VFuncInfoFlagsMustNotOverride = 4
    fromEnum VFuncInfoFlagsThrows = 8
    fromEnum (AnotherVFuncInfoFlags k) = k

    toEnum 1 = VFuncInfoFlagsMustChainUp
    toEnum 2 = VFuncInfoFlagsMustOverride
    toEnum 4 = VFuncInfoFlagsMustNotOverride
    toEnum 8 = VFuncInfoFlagsThrows
    toEnum k = AnotherVFuncInfoFlags k

instance P.Ord VFuncInfoFlags where
    compare a b = P.compare (P.fromEnum a) (P.fromEnum b)

instance IsGFlag VFuncInfoFlags

-- Flags RepositoryLoadFlags
{- |
Flags that control how a typelib is loaded.
-}
data RepositoryLoadFlags = 
      RepositoryLoadFlagsIrepositoryLoadFlagLazy
    {- ^
    Lazily load the typelib.
    -}
    | AnotherRepositoryLoadFlags Int
    -- ^ Catch-all for unknown values
    deriving (Show, Eq)

instance P.Enum RepositoryLoadFlags where
    fromEnum RepositoryLoadFlagsIrepositoryLoadFlagLazy = 1
    fromEnum (AnotherRepositoryLoadFlags k) = k

    toEnum 1 = RepositoryLoadFlagsIrepositoryLoadFlagLazy
    toEnum k = AnotherRepositoryLoadFlags k

instance P.Ord RepositoryLoadFlags where
    compare a b = P.compare (P.fromEnum a) (P.fromEnum b)

instance IsGFlag RepositoryLoadFlags

-- Flags FunctionInfoFlags
{- |
Flags for a @/GIFunctionInfo/@ struct.
-}
data FunctionInfoFlags = 
      FunctionInfoFlagsIsMethod
    {- ^
    is a method.
    -}
    | FunctionInfoFlagsIsConstructor
    {- ^
    is a constructor.
    -}
    | FunctionInfoFlagsIsGetter
    {- ^
    is a getter of a @/GIPropertyInfo/@.
    -}
    | FunctionInfoFlagsIsSetter
    {- ^
    is a setter of a @/GIPropertyInfo/@.
    -}
    | FunctionInfoFlagsWrapsVfunc
    {- ^
    represents a virtual function.
    -}
    | FunctionInfoFlagsThrows
    {- ^
    the function may throw an error.
    -}
    | AnotherFunctionInfoFlags Int
    -- ^ Catch-all for unknown values
    deriving (Show, Eq)

instance P.Enum FunctionInfoFlags where
    fromEnum FunctionInfoFlagsIsMethod = 1
    fromEnum FunctionInfoFlagsIsConstructor = 2
    fromEnum FunctionInfoFlagsIsGetter = 4
    fromEnum FunctionInfoFlagsIsSetter = 8
    fromEnum FunctionInfoFlagsWrapsVfunc = 16
    fromEnum FunctionInfoFlagsThrows = 32
    fromEnum (AnotherFunctionInfoFlags k) = k

    toEnum 1 = FunctionInfoFlagsIsMethod
    toEnum 2 = FunctionInfoFlagsIsConstructor
    toEnum 4 = FunctionInfoFlagsIsGetter
    toEnum 8 = FunctionInfoFlagsIsSetter
    toEnum 16 = FunctionInfoFlagsWrapsVfunc
    toEnum 32 = FunctionInfoFlagsThrows
    toEnum k = AnotherFunctionInfoFlags k

instance P.Ord FunctionInfoFlags where
    compare a b = P.compare (P.fromEnum a) (P.fromEnum b)

instance IsGFlag FunctionInfoFlags

-- Flags FieldInfoFlags
{- |
Flags for a @/GIFieldInfo/@.
-}
data FieldInfoFlags = 
      FieldInfoFlagsReadable
    {- ^
    field is readable.
    -}
    | FieldInfoFlagsWritable
    {- ^
    field is writable.
    -}
    | AnotherFieldInfoFlags Int
    -- ^ Catch-all for unknown values
    deriving (Show, Eq)

instance P.Enum FieldInfoFlags where
    fromEnum FieldInfoFlagsReadable = 1
    fromEnum FieldInfoFlagsWritable = 2
    fromEnum (AnotherFieldInfoFlags k) = k

    toEnum 1 = FieldInfoFlagsReadable
    toEnum 2 = FieldInfoFlagsWritable
    toEnum k = AnotherFieldInfoFlags k

instance P.Ord FieldInfoFlags where
    compare a b = P.compare (P.fromEnum a) (P.fromEnum b)

instance IsGFlag FieldInfoFlags


